@@ -1235,12 +1235,15 @@ class InternetArchiveItem(models.Model):
                     # this is just a logging function so we can see
                     # what's going on
                     if sample_count == 100000:
+                        progress.console.print(
+                            "Buffer contains {} items".format(count)
+                        )
                         progress.console.print(f"{data}")
                         sample_count = 0
 
                     sample_count += 1
 
-                    if count == 1000:
+                    if count > 1000:
                         InternetArchiveItem.objects.bulk_create(batch_objects)
                         progress.console.print(
                             f"Flushing {len(batch_objects)} items."
